;; Generated package description from consult-hoogle.el  -*- no-byte-compile: t -*-
(define-package "consult-hoogle" "0.1.1.0.20240211.83945" "Hoogle frontend using consult" '((emacs "27.1") (consult "0.18") (haskell-mode "16.1")) :commit "c4d4df5f5e863970b6ec907c5650fe673c9cf32a" :authors '(("rahguzar" . "rahguzar@zohomail.eu")) :maintainer '("rahguzar" . "rahguzar@zohomail.eu") :keywords '("docs" "languages") :url "https://codeberg.org/rahguzar/consult-hoogle")
